Discussion
==========

This section is a discussion of various aspects of Game Theory related to the
Axelrod library.

Contents:

.. toctree::
   :maxdepth: 2

   axelrods_tournaments.rst
   strategy_archetypes.rst
   overview_of_past_tournaments.rst
   play_contexts.rst
   community/index.rst
